.wp-block[data-align=center]>.wp-block-video{
  text-align:center;
}

.wp-block-video{
  position:relative;
}
.wp-block-video.is-transient video{
  opacity:.3;
}
.wp-block-video .components-spinner{
  margin-right:-9px;
  margin-top:-9px;
  position:absolute;
  right:50%;
  top:50%;
}

.editor-video-poster-control .components-button{
  margin-left:8px;
}

.block-library-video-tracks-editor{
  z-index:159990;
}

.block-library-video-tracks-editor__track-list-track{
  padding-right:12px;
}

.block-library-video-tracks-editor__single-track-editor-kind-select{
  max-width:240px;
}

.block-library-video-tracks-editor__single-track-editor-edit-track-label,.block-library-video-tracks-editor__tracks-informative-message-title{
  color:#757575;
  display:block;
  font-size:11px;
  font-weight:500;
  margin-top:4px;
  text-transform:uppercase;
}

.block-library-video-tracks-editor>.components-popover__content{
  width:360px;
}

.block-library-video-tracks-editor__add-tracks-container .components-menu-group__label,.block-library-video-tracks-editor__track-list .components-menu-group__label{
  padding:0;
}

.block-library-video-tracks-editor__tracks-informative-message{
  padding:8px;
}
.block-library-video-tracks-editor__tracks-informative-message-description{
  margin-bottom:0;
}